package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsPlanMaintDetail;

/**
 * 保养计划明细Mapper接口
 *
 * @author xins
 * @date 2024-01-10
 */
public interface DmsPlanMaintDetailMapper
{
    /**
     * 查询保养计划明细
     *
     * @param planMaintDetailId 保养计划明细主键
     * @return 保养计划明细
     */
    public DmsPlanMaintDetail selectDmsPlanMaintDetailByPlanMaintDetailId(Long planMaintDetailId);

    /**
     * 查询保养计划明细列表
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 保养计划明细集合
     */
    public List<DmsPlanMaintDetail> selectDmsPlanMaintDetailList(DmsPlanMaintDetail dmsPlanMaintDetail);

    /**
     * 新增保养计划明细
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 结果
     */
    public int insertDmsPlanMaintDetail(DmsPlanMaintDetail dmsPlanMaintDetail);

    /**
     * 修改保养计划明细
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 结果
     */
    public int updateDmsPlanMaintDetail(DmsPlanMaintDetail dmsPlanMaintDetail);

    /**
     * 删除保养计划明细
     *
     * @param planMaintDetailId 保养计划明细主键
     * @return 结果
     */
    public int deleteDmsPlanMaintDetailByPlanMaintDetailId(Long planMaintDetailId);

    /**
     * 批量删除保养计划明细
     *
     * @param planMaintDetailIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsPlanMaintDetailByPlanMaintDetailIds(Long[] planMaintDetailIds);



    /**
     * 查询保养计划明细列表,join standard和station
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 保养计划明细集合
     */
    public List<DmsPlanMaintDetail> selectDmsPlanMaintDetailJoinList(DmsPlanMaintDetail dmsPlanMaintDetail);

    List<DmsPlanMaintDetail> selectDmsPlanMaintDetailListByPlanMaintId(Long planMaintId);


}
