package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsPlanMaintDetail;
import com.hw.dms.service.IDmsPlanMaintDetailService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 保养计划明细Controller
 *
 * @author xins
 * @date 2024-01-10
 */
@RestController
@RequestMapping("/maintDetail")
public class DmsPlanMaintDetailController extends BaseController
{
    @Autowired
    private IDmsPlanMaintDetailService dmsPlanMaintDetailService;

    /**
     * 查询保养计划明细列表
     */
    @RequiresPermissions("dms:maintDetail:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        startPage();
        List<DmsPlanMaintDetail> list = dmsPlanMaintDetailService.selectDmsPlanMaintDetailJoinList(dmsPlanMaintDetail);
        return getDataTable(list);
    }

    /**
     * 导出保养计划明细列表
     */
    @RequiresPermissions("dms:maintDetail:export")
    @Log(title = "保养计划明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        List<DmsPlanMaintDetail> list = dmsPlanMaintDetailService.selectDmsPlanMaintDetailList(dmsPlanMaintDetail);
        ExcelUtil<DmsPlanMaintDetail> util = new ExcelUtil<DmsPlanMaintDetail>(DmsPlanMaintDetail.class);
        util.exportExcel(response, list, "保养计划明细数据");
    }

    /**
     * 获取保养计划明细详细信息
     */
    @RequiresPermissions("dms:maintDetail:query")
    @GetMapping(value = "/{planMaintDetailId}")
    public AjaxResult getInfo(@PathVariable("planMaintDetailId") Long planMaintDetailId)
    {
        return success(dmsPlanMaintDetailService.selectDmsPlanMaintDetailByPlanMaintDetailId(planMaintDetailId));
    }
    /**
     * 根据计划id获取保养计划明细列表
     * */
    @GetMapping("/getDmsPlanMaintDetail/{planMaintId}")
    public TableDataInfo getDmsPlanMaintDetail(@PathVariable("planMaintId") Long planMaintId){
        List<DmsPlanMaintDetail> dmsPlanMaintDetails = dmsPlanMaintDetailService.selectDmsPlanMaintDetailListByPlanMaintId(planMaintId);
        return getDataTable(dmsPlanMaintDetails);
    }

    /**
     * 新增保养计划明细
     */
    @RequiresPermissions("dms:maintDetail:add")
    @Log(title = "保养计划明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        return toAjax(dmsPlanMaintDetailService.insertDmsPlanMaintDetail(dmsPlanMaintDetail));
    }

    /**
     * 修改保养计划明细
     */
    @RequiresPermissions("dms:maintDetail:edit")
    @Log(title = "保养计划明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        return toAjax(dmsPlanMaintDetailService.updateDmsPlanMaintDetail(dmsPlanMaintDetail));
    }

    /**
     * 删除保养计划明细
     */
    @RequiresPermissions("dms:maintDetail:remove")
    @Log(title = "保养计划明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{planMaintDetailIds}")
    public AjaxResult remove(@PathVariable Long[] planMaintDetailIds)
    {
        return toAjax(dmsPlanMaintDetailService.deleteDmsPlanMaintDetailByPlanMaintDetailIds(planMaintDetailIds));
    }
}
